package io.skore.smooch_plugin.util

import android.annotation.SuppressLint
import android.content.Context
import android.content.res.Configuration
import android.os.Build
import android.util.Log
import java.util.*

object LangPreference {
    private val TAG = LangPreference::class.java.simpleName

    private const val LANG_PREFS = "LANG_PREFS"
    private const val USER_LANG = "USER_LANG"
    private const val COMPANY_LANG = "COMPANY_LANG"
    private const val DEFAULT_LANG = ""

    fun getUserLang(context: Context): String {
        return context.getSharedPreferences(LANG_PREFS, Context.MODE_PRIVATE)?.run {
            getString(USER_LANG, DEFAULT_LANG)
        } ?: DEFAULT_LANG
    }

    fun getCompanyLang(context: Context): String {
        return context.getSharedPreferences(LANG_PREFS, Context.MODE_PRIVATE)?.run {
            getString(COMPANY_LANG, DEFAULT_LANG)
        } ?: DEFAULT_LANG
    }

    fun getLang(context: Context): String {
        return context.getSharedPreferences(LANG_PREFS, Context.MODE_PRIVATE)?.run {
            val userLang = getString(USER_LANG, DEFAULT_LANG)
            val companyLang = getString(COMPANY_LANG, DEFAULT_LANG)
            if (userLang == null || userLang.isEmpty()) companyLang else userLang
        } ?: DEFAULT_LANG
    }

    fun updateResources(context: Context, language: String?): Context {
        val locale: Locale = when (language?.toLowerCase(Locale.ENGLISH)) {
            "pt",
            "pt-br" -> Locale("pt", "BR")
            "es",
            "es-es",
            "es-mx" -> Locale("es", "MX")
            "en",
            "en-us" -> Locale("en", "US")
            else -> {
                Log.w(TAG, "Invalid language type. Using english.")
                Locale("en", "US")
            }
        }

        return Configuration(context.resources.configuration).let {
            Locale.setDefault(locale)
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
                it.setLocale(locale)
            } else {
                @Suppress("DEPRECATION")
                it.locale = locale
            }
            context.createConfigurationContext(it)
        }
    }

    @SuppressLint("ApplySharedPref")
    fun setUserLang(context: Context, language: String?) {
        context.getSharedPreferences(LANG_PREFS, Context.MODE_PRIVATE)?.run {
            edit()?.apply {
                putString(USER_LANG, language ?: "")
                commit()
            }
        }
    }

    @SuppressLint("ApplySharedPref")
    fun setCompanyLang(context: Context, language: String?) {
        context.getSharedPreferences(LANG_PREFS, Context.MODE_PRIVATE)?.run {
            edit()?.apply {
                putString(COMPANY_LANG, language ?: "")
                commit()
            }
        }
    }
}