import 'dart:async';

import 'package:flutter/services.dart';

typedef Future<dynamic> MethodChannelHandler(Map<String, dynamic> arguments);

class SmoochPlugin {
  static const MethodChannel _channel = const MethodChannel('smooch_plugin');

  SmoochPlugin();

  static Future<bool> init({String appId, String userId, String smoochToken, List<String> menuItemsAllowed, String chatColor, Map<String, dynamic> userProperties}) async {
    var arguments = <String, dynamic>{
      'appId': appId,
      'userId': userId,
      'smoochToken': smoochToken,
      'menuItemsAllowed': menuItemsAllowed,
      'chatColor': chatColor,
      'properties': userProperties
    };
    final int result = await _channel.invokeMethod('init', arguments);
    return result == 0;
  }

  static Future<bool> show({String lang, bool sendStart, Map<String, String> accessory}) async {
    var arguments = <String, dynamic>{'lang': lang, 'sendStart': sendStart, 'accessory': accessory};
    final int result = await _channel.invokeMethod('show', arguments);
    return result == 0;
  }

  static Future<bool> logout() async {
    final int result = await _channel.invokeMethod("logout");
    return result == 0;
  }

  static Future<bool> minimize() async {
    final int result = await _channel.invokeMethod("minimize");
    return result == 0;
  }

  static void initializeChannel({onUpdateUnreadCount, onHandleMessageAction, onLogout, onHelpClick, MethodChannelHandler onPushNotification}) {
    _channel.setMethodCallHandler((MethodCall call) async {
      String method = call.method;
      dynamic arguments = call.arguments;

      if (method == "logoutComplete") {
        if (onLogout != null) onLogout();
      } else if (method == "updateChatUnreadCount") {
        if (onUpdateUnreadCount != null) onUpdateUnreadCount(arguments);
      } else if (method == "handleMessageAction") {
        if (onHandleMessageAction != null) onHandleMessageAction(arguments);
      } else if (method == "onHelpClick") {
        if (onHelpClick != null) onHelpClick();
      } else if (method == "onPushNotification") {
        if (onPushNotification != null) onPushNotification(arguments.cast<String, dynamic>());
      }
    });
  }
}
